@@ -102,10 +102,11 @@ finalfit_remove_p = ff_remove_p
 #'   summary_factorlist(dependent, explanatory) %>%
 #'   ff_percent_only()
 ff_percent_only <- function(.data){
+	if(!any(names(.data) == "label")) stop("summary_factorlist() must include: add_dependent_label = FALSE")
 	.data %>% 
-		dplyr::mutate_at(-c(1,2), ~ dplyr::case_when(!levels %in% c("Mean (SD)", "Median (IQR)") ~ 
-																								 	stringr::str_extract(., "(?<=\\().+?(?=\\))"), 
-																								 TRUE ~ .))
+		dplyr::mutate_at(vars(-dplyr::one_of("label", "levels", "p")), ~ dplyr::case_when(
+			!levels %in% c("Mean (SD)", "Median (IQR)") ~ stringr::str_extract(., "(?<=\\().+?(?=\\))"), 
+			TRUE ~ .))
 }
 
 #' @rdname ff_percent_only
