@@ -825,7 +825,7 @@ globalVariables(c("L95", "U95", "fit_id", "Total", "dependent",
 									"w", "Freq", "g", "total_prop", "Prop", "index_total", "vname", "Combined",
 									"2.5 %", "97.5 %", "p.value", "estimate", "index", "n", "missing_n", "var_type",
 									"missing_percent", "var1", "var2", "keep", "label", "rowid", "term",
-									"confint_L", "confint_U", "explanatory", "p", "where", "confint.level"))
+									"confint_L", "confint_U", "explanatory", "p", "where", "confint.level", "f"))
 
 
 # Workaround ::: as summary.formula not (yet) exported from Hmisc
